import {Component, HostListener, OnInit} from '@angular/core';
import {ViewModus} from './dao/viewModus';
import * as AOS from 'aos';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.scss']
})
export class AppComponent implements OnInit {
  view = 'desktopView';

  cookieMessage = 'Es gibt leider ein paar Menschen, die das Internet nicht bedienen können. Darum auch hier die nervige Meldung, dass wir Cookies verwenden. Klick es einfach weg.';
  cookieDismiss = 'Ok';
  cookieLinkText = 'Mehr Informationen über Cookies findest du hier';

  ngOnInit(): void {
    AOS.init();
    const width = window.innerWidth;
    this.setView(width);

    const cc = window as any;
    cc.cookieconsent.initialise({
      palette: {
        popup: {
          background: '#5e27b7'
        },
        button: {
          background: '#ffd740',
          text: '#000000'
        }
      },
      theme: 'edgeless',
      content: {
        message: this.cookieMessage,
        dismiss: this.cookieDismiss,
        link: this.cookieLinkText,
        href: './#/impressum'
      },
      position: 'top',
      static: true
    });
  }

  constructor(private screen: ViewModus){}

  @HostListener('window:resize', ['$event'])
  onResize($event: any): any {
    const width = window.innerWidth;
    this.setView(width);
  }

  setView(width: number): void {
    if (width < 768) {
      this.view = 'mobileView';
    } else if (width < 1024){
      this.view = 'tabletView';
    } else {
      this.view = 'desktopView';
    }
    this.screen.setNewView(this.view);
  }
}
